@@ -1,3 +1,4 @@
+from pysolarfocus.components.base.performance_calculator import PerformanceCalculator
 from .base.component import Component
 from .base.enums import DataTypes,RegisterTypes
 from .base.data_value import DataValue
@@ -27,4 +28,10 @@ class HeatPump(Component):
         
         self.evu_lock = DataValue(address=0,register_type=RegisterTypes.Holding)
         self.smart_grid = DataValue(address=1,register_type=RegisterTypes.Holding)
-        self.outdoor_temperature_external = DataValue(address=2,multiplier=10,register_type=RegisterTypes.Holding)
\ No newline at end of file
+        self.outdoor_temperature_external = DataValue(address=2,multiplier=10,register_type=RegisterTypes.Holding)
+
+        self.cop_heating = PerformanceCalculator(self.thermal_power_heating, self.electrical_power)
+        self.cop_cooling = PerformanceCalculator(self.thermal_power_cooling, self.electrical_power)
+        self.performance_overall = PerformanceCalculator(self.thermal_energy_total, self.electrical_energy_total)
+        self.performance_overall_heating = PerformanceCalculator(self.thermal_energy_heating, self.electrical_energy_heating)
+        self.performance_overall_drinking_water = PerformanceCalculator(self.thermal_energy_drinking_water, self.electrical_energy_drinking_water)
\ No newline at end of file
